@@ -1,7 +1,7 @@
 use strict;
 package Dist::Zilla::PluginBundle::Author::MAXHQ;
 # ABSTRACT: MAXHQ's default Dist::Zilla configuration
-$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.001003';
+$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.001004';
 #pod =encoding UTF-8
 #pod  
 #pod =head1 SYNOPSIS
@@ -19,7 +19,11 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.001003';
 #pod 	# Files included
 #pod 	#
 #pod 	[GatherDir]
+#pod 	prune_directory = ^.build$
+#pod 	prune_directory = ^.git$
+#pod 	prune_directory = ^.svn$
 #pod 	prune_directory = ^extlib$
+#pod 	prune_directory = ^CVS$
 #pod 	include_dotfiles = 1
 #pod 	
 #pod 	[PruneCruft]
@@ -144,7 +148,7 @@ sub configure {
 		#
 		['GatherDir' => {                 # skip files on top level
 			exclude_match => \@exclude_matches,
-			prune_directory => ['^extlib$'],
+			prune_directory => ['^extlib$', '^\.git$', '\.build$'],
 			include_dotfiles => 1, # needed e.g. for ".devdir"
 		}],
 		'PruneCruft',                     # prune stuff you probably don't want
@@ -241,7 +245,7 @@ __PACKAGE__->meta->make_immutable;
 {
 	package Dist::Zilla::Plugin::ShareDir::ProjectDistDir;
 	# ABSTRACT: install a directory's contents as "ShareDir" content
-$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '1.001003';
+$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '1.001004';
 use Moose;
 	use namespace::autoclean;
 
@@ -289,7 +293,7 @@ Dist::Zilla::PluginBundle::Author::MAXHQ - MAXHQ's default Dist::Zilla configura
 
 =head1 VERSION
 
-version 1.001003
+version 1.001004
 
 =head1 SYNOPSIS
 
@@ -306,7 +310,11 @@ Currently this plugin bundle is equivalent to:
 	# Files included
 	#
 	[GatherDir]
+	prune_directory = ^.build$
+	prune_directory = ^.git$
+	prune_directory = ^.svn$
 	prune_directory = ^extlib$
+	prune_directory = ^CVS$
 	include_dotfiles = 1
 	
 	[PruneCruft]
